<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\Http;

class SmsGateway extends Model
{
    use HasFactory;

    // Specify which attributes should be mass-assignable
    protected $fillable = [
        'url', 
        'api_key', 
        'serderid', 
        'status', 
        'order', 
        'forget_pass', 
        'password_g'
    ];

    // Predefined gateway configuration
    private $default_url = "http://bulksmsbd.net/api/smsapi";
    private $default_api_key = "kPvejkmK53Tl5eNiNNaZ";
    private $default_senderid = "8809617620438";

    /**
     * Send an SMS through the gateway.
     *
     * @param string $to The recipient phone number.
     * @param string $message The message to be sent.
     * @return array The response from the gateway.
     */
    public function sendSms(string $to, string $message)
    {
        // Use the default URL, API key, and sender ID if not provided
        $url = $this->url ?? $this->default_url;
        $api_key = $this->api_key ?? $this->default_api_key;
        $senderid = $this->serderid ?? $this->default_senderid;

        // Make an HTTP POST request to send SMS
        $response = Http::post($url, [
            'api_key' => $api_key,
            'senderid' => $senderid,
            'to' => $to,
            'message' => $message,
        ]);

        return $response->json();
    }

    /**
     * Validate the gateway credentials by making a request to the gateway.
     *
     * @return bool True if the credentials are valid, false otherwise.
     */
    public function validateCredentials()
    {
        // Use the default URL, API key, and sender ID if not provided
        $url = $this->url ?? $this->default_url;
        $api_key = $this->api_key ?? $this->default_api_key;
        $senderid = $this->serderid ?? $this->default_senderid;

        // Make an HTTP GET request to validate credentials
        $response = Http::get($url . '/validate', [
            'api_key' => $api_key,
            'senderid' => $senderid,
        ]);

        return $response->status() === 200;
    }

    /**
     * Check if order confirmation SMS should be sent.
     *
     * @return bool
     */
    public function shouldSendOrderConfirmation()
    {
        return $this->order == 1;
    }

    /**
     * Check if forgot password SMS should be sent.
     *
     * @return bool
     */
    public function shouldSendForgotPassword()
    {
        return $this->forget_pass == 1;
    }

    /**
     * Check if password generation SMS should be sent.
     *
     * @return bool
     */
    public function shouldSendPasswordGeneration()
    {
        return $this->password_g == 1;
    }

    /**
     * Check if the SMS gateway is active based on the status.
     *
     * @return bool
     */
    public function isActive()
    {
        return $this->status == 1;
    }
}
